[m-dev.] trival diff: add missing MR_ prefixes in library

Peter Ross peter.ross at miscrit.be
Wed Dec 6 23:04:26 AEDT 2000


Hi,


===================================================================


Estimated hours taken: 0.1


library/builtin.m:
library/std_util.m:
    Add missing MR_ prefixes.


Index: library/builtin.m
===================================================================
RCS file: /home/mercury1/repository/mercury/library/builtin.m,v
retrieving revision 1.47
diff -u -r1.47 builtin.m
--- library/builtin.m	2000/12/03 02:22:45	1.47
+++ library/builtin.m	2000/12/06 12:01:15
@@ -411,12 +411,12 @@
 aliasing, and in particular the lack of support for `ui' modes.
 :- pragma c_code(copy(Value::ui, Copy::uo), "
 	MR_save_transient_registers();
-	Copy = deep_copy(&Value, TypeInfo_for_T, NULL, NULL);
+	Copy = MR_deep_copy(&Value, TypeInfo_for_T, NULL, NULL);
 	MR_restore_transient_registers();
 ").
 :- pragma c_code(copy(Value::in, Copy::uo), "
 	MR_save_transient_registers();
-	Copy = deep_copy(&Value, TypeInfo_for_T, NULL, NULL);
+	Copy = MR_deep_copy(&Value, TypeInfo_for_T, NULL, NULL);
 	MR_restore_transient_registers();
 ").
 *************/
@@ -441,7 +441,8 @@
 	MR_Box value, MR_Box * copy)
 {
 	MR_Word val = (MR_Word) value;
-	*copy = (MR_Box) deep_copy(&val, (MR_TypeInfo) type_info, NULL, NULL);
+	*copy = (MR_Box) MR_deep_copy(&val,
+			(MR_TypeInfo) type_info, NULL, NULL);
 }
 
 void MR_CALL
Index: library/std_util.m
===================================================================
RCS file: /home/mercury1/repository/mercury/library/std_util.m,v
retrieving revision 1.210
diff -u -r1.210 std_util.m
--- library/std_util.m	2000/12/06 06:05:37	1.210
+++ library/std_util.m	2000/12/06 12:01:17
@@ -878,13 +878,13 @@
 #else
   /*
   ** Note that we need to save/restore the MR_hp register, if it
   ** is transient, before/after calling deep_copy().
   */
   #define MR_PARTIAL_DEEP_COPY(SolutionsHeapPtr,			\\
   		OldVar, NewVal, TypeInfo_for_T)				\\
   	do {								\\
 		MR_save_transient_hp();					\\
-		NewVal = deep_copy(&OldVal, (MR_TypeInfo) TypeInfo_for_T,\\
+		NewVal = MR_deep_copy(&OldVal, (MR_TypeInfo) TypeInfo_for_T,\\
 				(const MR_Word *) SolutionsHeapPtr,	\\
 				MR_ENGINE(solutions_heap_zone)->top);	\\
 		MR_restore_transient_hp();				\\
@@ -2656,7 +2656,7 @@
 **  call MR_save_transient_registers(), and afterwards, call
 **  MR_restore_transient_registers().
 **
 **  If writing a C function that calls deep_copy, make sure you
 **  document that around your function, MR_save_transient_registers()
 **  MR_restore_transient_registers() need to be used.
 **

--------------------------------------------------------------------------
mercury-developers mailing list
Post messages to:       mercury-developers at cs.mu.oz.au
Administrative Queries: owner-mercury-developers at cs.mu.oz.au
Subscriptions:          mercury-developers-request at cs.mu.oz.au
--------------------------------------------------------------------------
@@ -878,13 +878,13 @@
   /*
   ** Note that we need to save/restore the MR_hp register, if it
-  ** is transient, before/after calling deep_copy().
+  ** is transient, before/after calling MR_deep_copy().
   */
   #define MR_PARTIAL_DEEP_COPY(SolutionsHeapPtr,			\\
@@ -2656,7 +2656,7 @@
 **  MR_restore_transient_registers().
 **
-**  If writing a C function that calls deep_copy, make sure you
+**  If writing a C function that calls MR_deep_copy, make sure you
 **  document that around your function, MR_save_transient_registers()
 **  MR_restore_transient_registers() need to be used.



More information about the developers mailing list